==> apache-paimon-0.6.1-incubating-src.tgz: paimon-0.6.1-incubating/paimon-spark/paimon-spark-common/src/main/scala/org/apache/paimon/spark/catalyst/plans/logical/PaimonCallStatement.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.paimon.spark.catalyst.plans.logical

import org.apache.spark.sql.catalyst.expressions.Expression
import org.apache.spark.sql.catalyst.plans.logical.LeafParsedStatement

/** A CALL statement parsed from SQL. */
case class PaimonCallStatement(name: Seq[String], args: Seq[PaimonCallArgument])
  extends LeafParsedStatement

/** An argument of a CALL statement. */
sealed trait PaimonCallArgument {

  def expr: Expression
}

/** An argument identified by name. */
case class PaimonNamedArgument(name: String, expr: Expression) extends PaimonCallArgument

/** An argument identified by position. */
case class PaimonPositionalArgument(expr: Expression) extends PaimonCallArgument

==> apache-paimon-0.7.0-incubating-src.tgz: paimon-0.7.0-incubating/paimon-spark/paimon-spark-common/src/main/scala/org/apache/paimon/spark/catalyst/plans/logical/PaimonCallStatement.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.paimon.spark.catalyst.plans.logical

import org.apache.paimon.spark.leafnode.PaimonLeafParsedStatement

import org.apache.spark.sql.catalyst.expressions.Expression

/** A CALL statement parsed from SQL. */
case class PaimonCallStatement(name: Seq[String], args: Seq[PaimonCallArgument])
  extends PaimonLeafParsedStatement

/** An argument of a CALL statement. */
sealed trait PaimonCallArgument {

  def expr: Expression
}

/** An argument identified by name. */
case class PaimonNamedArgument(name: String, expr: Expression) extends PaimonCallArgument

/** An argument identified by position. */
case class PaimonPositionalArgument(expr: Expression) extends PaimonCallArgument
